#
# spec file for package python-gnupg
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-gnupg
Version:        0.3.7
Release:        4.1
Url:            http://code.google.com/p/python-gnupg/
Summary:        A wrapper for the Gnu Privacy Guard (GPG or GnuPG)
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/p/python-gnupg/python-gnupg-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This module allows easy access to GnuPG's key management, encryption and
signature functionality from Python programs. It is intended for use with
Python 2.4 or greater.

%prep
%setup -q -n python-gnupg-%{version}
# fix end of line
sed -i 's/\r//' README.rst

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE.txt README.rst
%{python_sitelib}/*

%changelog
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.3.7:
  * Added an output keyword parameter to the sign and sign_file
    methods, to allow writing the signature to a file
  * Allowed specifying True for the sign keyword parameter, which
    allows use of the default key for signing and avoids having to
    specify a key id when it's desired to use the default
  * Used a uniform approach with subprocess on Windows and POSIX:
    shell=True is not used on either
  * When signing/verifying, the status is updated to reflect any
    expired or revoked keys or signatures
  * Handled 'NOTATION_NAME' and 'NOTATION_DATA' during verification
  * Fixed #1, #16, #18, #20: Quoting approach changed, since now
    shell=False
  * Fixed #14: Handled 'NEED_PASSPHRASE_PIN' message
  * Fixed #8: Added a scan_keys method to allow scanning of keys
    without the need to import into a keyring
  * Fixed #5: Added '0x' prefix when searching for keys
  * Fixed #4: Handled 'PROGRESS' message during encryption
  * Fixed #3: Changed default encoding to Latin-1
  * Fixed #2: Raised ValueError if no recipients were specified for
    an asymmetric encryption request
  * Handled 'UNEXPECTED' message during verification
  * Replaced old range(len(X)) idiom with enumerate()
  * Refactored ListKeys / SearchKeys classes to maximise use of
    common functions
  * Fixed GC94: Added export-minimal and armor options when
    exporting keys
- additional changes from version 0.3.6:
  * Fixed GC82: Enabled fast random tests on gpg as well as gpg2
  * Fixed GC85: Avoided deleting temporary file to preserve its
    permissions
  * Fixed GC87: Avoided writing passphrase to log
  * Fixed GC95: Added verify_data() method to allow verification of
    signatures in memory
  * Fixed GC96: Regularised end-of-line characters
  * Fixed GC98: Rectified problems with earlier fix for shell
    injection
- point the source URL to pypi
- fix end of line of README.rst
- rename LICENSE.txt and README.rst to follow upstream
* Wed Dec 11 2013 p.drouand@gmail.com
- Update to version 0.3.5
  + Added shell quoting to guard against shell injection.
  + Fixed issues #76, #77, #78, #79 and #80.
- Changes from 0.3.4
  + Addresses #65, #66, #67, #68 and #70.
- Changes from 0.3.3
  + Addresses issues #57, #61, #62 and #63.
* Thu Jan 17 2013 alexandre@exatati.com.br
- Update to 0.3.2:
  - Fixed Issue #56: Disallow blank values in key generation.
  - Fixed Issue #57: Handle colons and other characters in list_keys.
  - Fixed Issue #59 and Issue #60: Handle INV_SGNR status during
    verification and removed calls requiring interactive password
    input from doctests.
* Mon Jan 14 2013 saschpe@suse.de
- Simplify macro usage
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
* Sat Sep  1 2012 alexandre@exatati.com.br
- Update to 0.3.1:
  - Fixed Issue #45 : Allow additional arguments to gpg executable.
    Fixed Issue #50 : Use latin-1 encoding in tests when it's known
    to be required.
    Fixed Issue #51: Test now returns non-zero exit status on test
    failure.
    Fixed Issue #53: Now handles INV_SGNR and KEY_NOT_CREATED
    statuses.
    Fixed Issue #55: Verification and decryption now return trust
    level of signer in integer and text form.
* Sat May 12 2012 alexandre@exatati.com.br
- Update to 0.3.0:
  - Fixed  Issue #49 : Reinstated Yann Leboulanger's change to
    support subkeys (accidentally left out in 0.2.7).
* Fri Mar 30 2012 alexandre@exatati.com.br
- Update to 0.2.9:
  - Fixed  Issue #36 : Now handles CARDCTRL and POLICY_URL messages.
  - Fixed  Issue #40 : Now handles DECRYPTION_INFO, DECRYPTION_FAILED
    and DECRYPTION_OKAY messages. The random_binary_data file is no
    longer shipped, but constructed by the test suite if needed.
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Sat Sep  3 2011 alexandre@exatati.com.br
- Update to 0.2.8:
  - Fixed  Issue #29 : Now handles IMPORT_RES while verifying.
  - Fixed  Issue #30 : Fixed an encoding problem.
  - Fixed  Issue #33 : Quoted arguments for added safety.
* Wed Apr 13 2011 alexandre@exatati.com.br
- Update to 0.2.7:
  - Fixed Issue #24 : License is clarified as BSD.
  - Fixed Issue #25 : Incorporated Daniel Folkinshteyn's changes.
  - Fixed Issue #26 : Incorporated Yann Leboulanger's subkey change.
  - Fixed Issue #27 : Incorporated hysterix's support for symmetric
    encryption. Also did some internal cleanups of Unicode handling.
- Regenerate spec file with py2pack;
- Add LICENSE and README files as documentation.
* Tue Jan 25 2011 alexandre@exatati.com.br
- Update to 0.2.6;
- Bzip2 source file.
* Sun May 30 2010 alexandre@exatati.com.br
- Initial package (0.2.4) for openSUSE.
